<?php
    
    namespace artbox\catalog\models;

    use artbox\core\behaviors\SlugBehavior;
    use artbox\core\models\Alias;
    use artbox\core\models\Language;
    use Yii;
    use yii\db\ActiveRecord;

    /**
     * This is the model class for table "brand_lang".
     *
     * @property integer  $brand_id
     * @property integer  $language_id
     * @property string   $title
     * @property integer  $alias_id
     * @property string   $description
     *
     * @property Alias    $alias
     * @property Brand    $brand
     * @property Language $language
     */
    class BrandLang extends ActiveRecord
    {
        /**
         * @inheritdoc
         */
        public static function tableName()
        {
            return 'brand_lang';
        }
        
        /**
         * @inheritdoc
         */
        public function behaviors()
        {
            return [
                'slug' => [
                    'class'  => SlugBehavior::className(),
                    'action' => 'brand/view',
                    'params' => [
                        'id' => 'brand_id',
                    ],
                    'fields' => [
                        'title'       => \Yii::t('catalog', 'Brand title'),
                        'description' => \Yii::t('catalog', 'Brand description'),
                    ],
                ],
            ];
        }
    
        /**
         * @inheritdoc
         */
        public function rules()
        {
            return [
                [
                    [
                        'title',
                    ],
                    'required',
                ],
                [
                    [ 'description' ],
                    'string',
                ],
                [
                    [
                        'title',
                        'aliasValue',
                    ],
                    'string',
                    'max' => 255,
                ],
            ];
        }
        
        /**
         * @inheritdoc
         */
        public function attributeLabels()
        {
            return [
                'brand_id'    => Yii::t('catalog', 'Brand ID'),
                'language_id' => Yii::t('catalog', 'Language ID'),
                'title'       => Yii::t('catalog', 'Title'),
                'alias_id'    => Yii::t('catalog', 'Alias ID'),
                'description' => Yii::t('catalog', 'Description'),
            ];
        }
        
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getAlias()
        {
            return $this->hasOne(Alias::className(), [ 'id' => 'alias_id' ]);
        }
        
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getBrand()
        {
            return $this->hasOne(Brand::className(), [ 'id' => 'brand_id' ])
                        ->inverseOf('brandLangs');
        }
        
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getLanguage()
        {
            return $this->hasOne(Language::className(), [ 'id' => 'language_id' ]);
        }
    }
