<?php
    namespace artbox\catalog\models;

    use artbox\core\models\Alias;
    use yii\base\Object;
    use yii\db\ActiveQuery;
    use yii\helpers\Json;

    /**
     * Class Filter
     * The stub class to identify dynamic filters
     *
     * @property bool $isTop
     * @property bool $isNew
     * @property bool $isSale
     * @property bool $isExclusive
     * @package artbox\catalog\models
     */
    class Filter extends Object
    {
        /**
         * Stub property
         *
         * @var null
         */
        public $fields = null;
    
        protected $rewritedFilters = null;
    
        /**
         * @var bool
         */
        public $isTop = '';
    
        /**
         * @var bool
         */
        public $isNew = '';
    
        /**
         * @var bool
         */
        public $isSale = '';
    
        /**
         * @var bool
         */
        public $isExclusive = '';
    
        public function init()
        {
            $url = \Yii::$app->request->url;
    
            if (strpos($url, 'is-top')) {
                $this->isTop = 'is-top';
            }
            if (strpos($url, 'is-new')) {
                $this->isNew = 'is-new';
            }
            if (strpos($url, 'is-sale')) {
                $this->isSale = 'is-sale';
            }
            if (strpos($url, 'is-excl')) {
                $this->isExclusive = 'is-excl';
            }
    
            $aliases = \Yii::$app->db->cache(
                function () {
                    return Alias::find()
                                ->where(
                                    [
                                        'entity' => self::className(),
                                    ]
                                )
                                ->asArray()
                                ->all();
                }
            );
            
            $rewritedFilters = [];
            foreach ($aliases as $alias) {
                $element = Json::decode($alias[ 'route' ]);
                /**
                 * @todo Fix hard coded 'catalog'
                 */
                $filter = '/catalog/' . $element[ 'category' ] . '/' . $element[ 'filter' ];
                $rewritedFilters[ $filter ] = '/' . $alias[ 'value' ];
            }
    
            $this->rewritedFilters = $rewritedFilters;
        }
    
        public function replaceFilterUrl(string $url)
        {
            $return = $url;
            if (array_key_exists($url, $this->rewritedFilters)) {
                $return = $this->rewritedFilters[ $url ];
            }
            if (preg_match('#^/catalog/[\w-]+/[\w-]+$#', $return)) {
                if ($this->isTop) {
                    $return .= '_is-top';
                }
                if ($this->isNew) {
                    $return .= '_is-new';
                }
                if ($this->isSale) {
                    $return .= '_is-sale';
                }
                if ($this->isExclusive) {
                    $return .= '_is-excl';
                }
            }
    
            return $return;
        }
    
        public function parseQuery(ActiveQuery $query)
        {
            if ($this->isTop) {
                $query->andWhere('mask & 1 != 0');
            }
            if ($this->isNew) {
                $query->andWhere('mask & 2 != 0');
            }
            if ($this->isSale) {
                $query->andWhere('mask & 4 != 0');
            }
            if ($this->isExclusive) {
                $query->andWhere('mask & 8 != 0');
            }
        }
    }