<?php
    /**
     * @var View                               $this
     * @var Category[]                         $categories
     * @var ProductOptionGroupExclToCategory[] $currentCategories
     */
    
    use artbox\catalog\models\Category;
    use artbox\catalog\models\ProductOptionGroupExclToCategory;
    use kartik\select2\Select2;
    use yii\helpers\ArrayHelper;
    use yii\helpers\Html;
    use yii\web\View;

?>

<div class="row">
  <div class="col-sm-10">
      <?php
          echo Select2::widget(
              [
                  'id'           => 'category-select',
                  'name'         => 'nameless',
                  'data'         => ArrayHelper::map($categories, 'id', 'lang.title'),
                  'options'      => [
                      'placeholder' => \Yii::t('catalog', 'Select category ...'),
                  ],
                  'pluginEvents' => [
                      "select2:select" => "function(e) { 
                            $('#add-category-btn').attr('data-id', e.params.data.id); 
                            $('#add-category-btn').attr('data-title', e.params.data.text); 
                          }",
                  ],
              ]
          );
      ?>
  </div>
  <div class="col-sm-2">
      <?= Html::button(
          \Yii::t('catalog', 'Add'),
          [
              'class' => 'btn btn-success',
              'id'    => 'add-category-btn',
              'data'  => [
                  'id'    => '',
                  'title' => '',
              ],
          ]
      ) ?>
  </div>
</div>

<div class="table-responsive">
  <table class="table table-striped jambo_table">
    <thead>
      <tr class="headings">
        <th>Name</th>
        <th>Sort</th>
        <th>Status</th>
        <th>In menu</th>
        <th>Is filter</th>
        <th></th>
      </tr>
    </thead>
    <tbody>
        <?php
            foreach ($currentCategories as $currentCategory) { ?>
          
          <tr>
            <td>
                <?= $categories[ $currentCategory->category_id ]->lang->title ?>
            </td>
            <td>
                <?= Html::input(
                    'number',
                    'Categories[' . $currentCategory->category_id . '][sort]',
                    $currentCategory->sort,
                    [
                        'class' => 'form-control',
                    ]
                ) ?>
            </td>
            <td>
                <?= Html::checkbox(
                    'Categories[' . $currentCategory->category_id . '][status]',
                    $currentCategory->status,
                    [
                        'class' => 'flat',
                    ]
                ) ?>
            </td>
            <td>
                <?= Html::checkbox(
                    'Categories[' . $currentCategory->category_id . '][in_menu]',
                    $currentCategory->in_menu,
                    [
                        'class' => 'flat',
                    ]
                ) ?>
            </td>
            <td>
                <?= Html::checkbox(
                    'Categories[' . $currentCategory->category_id . '][is_filter]',
                    $currentCategory->is_filter,
                    [
                        'class' => 'flat',
                    ]
                ) ?>
            </td>
            <td>
                <?= Html::a(
                    '<span class="fa fa-trash"></span>',
                    '#',
                    [
                        'class' => 'delete-row',
                    ]
                ) ?>
            </td>
          </tr>
        
        <?php } ?>
    </tbody>
  </table>
</div>