<?php
    
    namespace artbox\core\models;
    
    use artbox\core\behaviors\LanguageBehavior;
    use yii\db\ActiveRecord;
    use yii\db\ActiveQuery;
    use yii\web\Request;
    
    /**
     * This is the model class for table "page_category".
     *
     * @property integer            $id
     * @property integer            $sort
     * @property boolean            $status
     * @property PageCategoryLang[] $pageCategoryLangs
     * @property Language[]         $languages
     * @property Page[]             $pages
     *      * From language behavior *
     * @property PageLang           $lang
     * @property PageLang[]         $langs
     * @property PageLang           $objectLang
     * @property string             $ownerKey
     * @property string             $langKey
     * @property PageLang[]         $modelLangs
     * @property bool               $transactionStatus
     * @method string       getOwnerKey()
     * @method void         setOwnerKey( string $value )
     * @method string       getLangKey()
     * @method void         setLangKey( string $value )
     * @method ActiveQuery  getLangs()
     * @method ActiveQuery  getLang( integer $language_id )
     * @method PageLang[]   generateLangs()
     * @method void         loadLangs( Request $request )
     * @method bool         linkLangs()
     * @method bool         saveLangs()
     * @method bool         getTransactionStatus()
     * @method bool         loadWithLangs( Request $request )
     * @method bool         saveWithLangs()
     *      * End language behavior *
     * @see LanguageBehavior
     */
    class PageCategory extends ActiveRecord
    {
        /**
         * @inheritdoc
         */
        public static function tableName()
        {
            return 'page_category';
        }
        
        /**
         * @inheritdoc
         */
        public function behaviors()
        {
            return [
                'language' => [
                    'class' => LanguageBehavior::className(),
                ],
            ];
        }
        
        /**
         * @inheritdoc
         */
        public function rules()
        {
            return [
                [
                    [ 'sort' ],
                    'integer',
                ],
                [
                    [ 'status' ],
                    'boolean',
                ],
            ];
        }
        
        /**
         * @inheritdoc
         */
        public function attributeLabels()
        {
            return [
                'id'     => 'ID',
                'sort'   => 'Sort',
                'status' => 'Status',
            ];
        }
        
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getPageCategoryLangs()
        {
            return $this->hasMany(PageCategoryLang::className(), [ 'page_category_id' => 'id' ]);
        }
        
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getLanguages()
        {
            return $this->hasMany(Language::className(), [ 'id' => 'language_id' ])
                        ->viaTable('page_category_lang', [ 'page_category_id' => 'id' ]);
        }
        
        /**
         * @return ActiveQuery
         */
        public function getPages()
        {
            return $this->hasMany(Page::className(), [ 'id' => 'page_id' ])
                        ->viaTable('page_to_category', [ 'category_id' => 'id' ]);
        }
    }
