<?php
    
    namespace artbox\core\models;
    
    use Yii;
    use yii\db\ActiveRecord;
    
    /**
     * This is the model class for table "slide_lang".
     *
     * @property integer  $slide_id
     * @property integer  $language_id
     * @property string   $link
     * @property integer  $image_id
     * @property string   $title
     * @property Image    $image
     * @property Language $language
     * @property Slide    $slide
     */
    class SlideLang extends ActiveRecord
    {
        /**
         * @inheritdoc
         */
        public static function tableName()
        {
            return 'slide_lang';
        }
        
        /**
         * @inheritdoc
         */
        public function rules()
        {
            return [
                [
                    [
                        'slide_id',
                        'language_id',
                        'image_id',
                    ],
                    'required',
                ],
                [
                    [
                        'slide_id',
                        'language_id',
                        'image_id',
                    ],
                    'integer',
                ],
                [
                    [
                        'link',
                        'title',
                    ],
                    'string',
                    'max' => 255,
                ],
                [
                    [ 'image_id' ],
                    'exist',
                    'skipOnError'     => true,
                    'targetClass'     => Image::className(),
                    'targetAttribute' => [ 'image_id' => 'id' ],
                ],
                [
                    [ 'language_id' ],
                    'exist',
                    'skipOnError'     => true,
                    'targetClass'     => Language::className(),
                    'targetAttribute' => [ 'language_id' => 'id' ],
                ],
                [
                    [ 'slide_id' ],
                    'exist',
                    'skipOnError'     => true,
                    'targetClass'     => Slide::className(),
                    'targetAttribute' => [ 'slide_id' => 'id' ],
                ],
            ];
        }
        
        /**
         * @inheritdoc
         */
        public function attributeLabels()
        {
            return [
                'slide_id'    => Yii::t('core', 'Slide ID'),
                'language_id' => Yii::t('core', 'Language ID'),
                'link'        => Yii::t('core', 'Link'),
                'image_id'    => Yii::t('core', 'Image ID'),
                'title'       => Yii::t('core', 'Title'),
            ];
        }
        
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getImage()
        {
            return $this->hasOne(Image::className(), [ 'id' => 'image_id' ]);
        }
        
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getLanguage()
        {
            return $this->hasOne(Language::className(), [ 'id' => 'language_id' ]);
        }
        
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getSlide()
        {
            return $this->hasOne(Slide::className(), [ 'id' => 'slide_id' ])
                        ->inverseOf('slideLangs');
        }
    
        public static function primaryKey()
        {
            return ['slide_id', 'language_id'];
        }
    
    }
