<?php
    
    use artbox\core\helpers\SlugifyDecorator;
    use artbox\core\models\Alias;
    use dosamigos\tinymce\TinyMce;
    use yii\helpers\Html;
    use yii\web\View;
    use yii\widgets\ActiveForm;
    
    /**
     * @var View       $this
     * @var Alias      $model
     * @var ActiveForm $form
     */
?>

<div class="alias-form">
    
    <?php $form = ActiveForm::begin(); ?>
    
    <?php
        $valueField = $form->field(
            $model,
            'value'
        )
                           ->hint(
                               \Yii::t(
                                   'core',
                                   '{field} field would be slugified.',
                                   [
                                       'field' => $model->getAttributeLabel('value'),
                                   ]
                               )
                           );
        echo SlugifyDecorator::decorate(
            $valueField,
            [ '/alias/slugify' ],
            $valueField,
            true,
            $model->language_id
        )
                             ->textInput() ?>
  
  <div class="row">
    <div class="col-xs-12 col-sm-3 pull-right right_border">
      <p>
          <?php
              echo \Yii::t('core', 'Available fields for current entity: ');
          ?>
      </p>
        <?php
            if (!empty($model->entity)) {
                ?>
              <div>
                <table class="table table-condensed borderless">
                    <?php
                        foreach ($model->getCheckedFields() as $field => $fieldTitle) {
                            ?>
                          <tr>
                            <td><?= $field ?></td>
                            <td>- <?= $fieldTitle ?></td>
                          </tr>
                            <?php
                        }
                    ?>
                </table>
              </div>
              <div>
                <hr>
                <p>
                    <?php
                        echo \Yii::t('core', 'to use them add to field in double brackets: ');
                    ?>
                </p>
                <pre style="white-space: normal; word-break: normal;">Your text with custom [[example]] field.</pre>
                <hr>
              </div>
                <?php
            } else {
                echo Html::tag('p', \Yii::t('core', 'No available fields.'));
            }
        ?>
    </div>
    <div class="col-xs-12 col-sm-9 right_border">
        <?= $form->field($model, 'title')
                 ->textInput() ?>
        
        <?= $form->field($model, 'description')
                 ->textarea() ?>
        
        <?= $form->field($model, 'h1')
                 ->textInput() ?>

        <?php
            echo $form->field($model, 'seo_text')
                      ->widget(
                          TinyMce::className(),
                          [
                              'options'       => [ 'rows' => 30 ],
                              'language'      => 'ru',
                              'clientOptions' => [
                                  'file_browser_callback' => new yii\web\JsExpression(
                                      "function(field_name, url, type, win) {
window.open('" . yii\helpers\Url::to(
                                          [
                                              'imagemanager/manager',
                                              'view-mode'   => 'iframe',
                                              'select-type' => 'tinymce',
                                          ]
                                      ) . "&tag_name='+field_name,'','width=800,height=540 ,toolbar=no,status=no,menubar=no,scrollbars=no,resizable=no');
}"
                                  ),
                                  'plugins'               => [
                                      "advlist autolink lists link charmap print preview anchor",
                                      "searchreplace visualblocks code fullscreen",
                                      "insertdatetime media table contextmenu paste image",
                                  ],
                                  'toolbar'               => "undo redo | styleselect | bold italic | alignleft aligncenter alignright alignjustify | bullist numlist outdent indent | link image | code",
                                  'image_advtab'          => true,
                              ],
                          ]
                      );
        ?>
    </div>
  </div>
    
    <?= $form->field($model, 'robots')
             ->dropDownList(
                 [
                     'index, follow'     => 'index, follow',
                     'index, nofollow'   => 'index, nofollow',
                     'noindex, follow'   => 'noindex, follow',
                     'noindex, nofollow' => 'noindex, nofollow',
                 ]
             ) ?>
  
  <div class="form-group">
      <?= Html::submitButton(
          $model->isNewRecord ? 'Create' : 'Update',
          [ 'class' => $model->isNewRecord ? 'btn btn-success' : 'btn btn-primary' ]
      ) ?>
  </div>
    
    <?php ActiveForm::end(); ?>

</div>
