<?php
    
    namespace artbox\order\models;
    
    use artbox\core\models\Language;
    use Yii;
    
    /**
     * This is the model class for table "delivery_lang".
     *
     * @property integer  $delivery_id
     * @property integer  $language_id
     * @property string   $title
     * @property string   $description
     * @property Delivery $delivery
     * @property Language $language
     */
    class DeliveryLang extends \yii\db\ActiveRecord
    {
        /**
         * @inheritdoc
         */
        public static function tableName()
        {
            return 'delivery_lang';
        }
        
        /**
         * @inheritdoc
         */
        public function rules()
        {
            return [
                [
                    [
                        'delivery_id',
                        'language_id',
                        'title',
                    ],
                    'required',
                ],
                [
                    [
                        'delivery_id',
                        'language_id',
                    ],
                    'integer',
                ],
                [
                    [ 'description' ],
                    'string',
                ],
                [
                    [ 'title' ],
                    'string',
                    'max' => 255,
                ],
                [
                    [ 'delivery_id' ],
                    'exist',
                    'skipOnError'     => true,
                    'targetClass'     => Delivery::className(),
                    'targetAttribute' => [ 'delivery_id' => 'id' ],
                ],
                [
                    [ 'language_id' ],
                    'exist',
                    'skipOnError'     => true,
                    'targetClass'     => Language::className(),
                    'targetAttribute' => [ 'language_id' => 'id' ],
                ],
            ];
        }
        
        /**
         * @inheritdoc
         */
        public function attributeLabels()
        {
            return [
                'delivery_id' => Yii::t('order', 'Delivery ID'),
                'language_id' => Yii::t('order', 'Language ID'),
                'title'       => Yii::t('order', 'Title'),
                'description' => Yii::t('order', 'Description'),
            ];
        }
        
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getDelivery()
        {
            return $this->hasOne(Delivery::className(), [ 'id' => 'delivery_id' ]);
        }
        
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getLanguage()
        {
            return $this->hasOne(Language::className(), [ 'id' => 'language_id' ]);
        }
    }
