<?php
    
    namespace artbox\order\models;
    
    use yii\base\Model;
    use yii\data\ActiveDataProvider;
    
    /**
     * DeliverySearch represents the model behind the search form about `artbox\order\models\Delivery`.
     */
    class DeliverySearch extends Delivery
    {
        public $title;
        
        /**
         * @inheritdoc
         */
        public function rules()
        {
            return [
                [
                    [ 'title' ],
                    'string',
                ],
                [
                    [
                        'id',
                        'sort',
                    ],
                    'integer',
                ],
                [
                    [ 'value' ],
                    'number',
                ],
                [
                    [ 'status' ],
                    'boolean',
                ],
            ];
        }
        
        /**
         * @inheritdoc
         */
        public function behaviors()
        {
            return [];
        }
        
        /**
         * @inheritdoc
         */
        public function scenarios()
        {
            // bypass scenarios() implementation in the parent class
            return Model::scenarios();
        }
        
        /**
         * Creates data provider instance with search query applied
         *
         * @param array $params
         *
         * @return ActiveDataProvider
         */
        public function search($params)
        {
            $query = Delivery::find()
                             ->joinWith('lang');
            
            // add conditions that should always apply here
            
            $dataProvider = new ActiveDataProvider(
                [
                    'query' => $query,
                    'sort'  => [
                        'attributes' => [
                            'title' => [
                                'asc'  => [ 'delivery_lang.title' => SORT_ASC ],
                                'desc' => [ 'delivery_lang.title' => SORT_DESC ],
                            ],
                            'id',
                            'value',
                            'status',
                        ],
                    ],
                ]
            );
            
            $this->load($params);
            
            if (!$this->validate()) {
                // uncomment the following line if you do not want to return any records when validation fails
                // $query->where('0=1');
                return $dataProvider;
            }
            
            // grid filtering conditions
            $query->andFilterWhere(
                [
                    'id'     => $this->id,
                    'sort'   => $this->sort,
                    'value'  => $this->value,
                    'status' => $this->status,
                ]
            );
            $query->andFilterWhere(
                [
                    'like',
                    'delivery_lang.title',
                    $this->title,
                ]
            );
            
            return $dataProvider;
        }
    }
