<?php
    
    namespace artbox\order\models;

    use artbox\core\behaviors\LanguageBehavior;
    use artbox\core\models\Language;
    use Yii;
    use yii\db\ActiveQuery;
    use yii\db\ActiveRecord;
    use yii\web\Request;

    /**
     * This is the model class for table "label".
     *
     * @property integer     $id
     * @property integer     $sort
     * @property string      $value
     * @property boolean     $status
     * @property string      $color
     * @property LabelLang[] $labelLangs
     * @property Language[]  $languages
     * @property Order[]     $orders
     *      * From language behavior *
     * @property LabelLang   $lang
     * @property LabelLang[] $langs
     * @property LabelLang   $objectLang
     * @property string      $ownerKey
     * @property string      $langKey
     * @property LabelLang[] $modelLangs
     * @property bool        $transactionStatus
     * @method string       getOwnerKey()
     * @method void         setOwnerKey( string $value )
     * @method string       getLangKey()
     * @method void         setLangKey( string $value )
     * @method ActiveQuery  getLangs()
     * @method ActiveQuery  getLang( integer $language_id )
     * @method LabelLang[]   generateLangs()
     * @method void         loadLangs( Request $request )
     * @method bool         linkLangs()
     * @method bool         saveLangs()
     * @method bool         getTransactionStatus()
     * @method bool         loadWithLangs( Request $request )
     * @method bool         saveWithLangs()
     *      * End language behavior *
     * @see LanguageBehavior
     */
    class Label extends ActiveRecord
    {
        /**
         * @inheritdoc
         */
        public static function tableName()
        {
            return 'label';
        }
    
        /**
         * @inheritdoc
         */
        public function behaviors()
        {
            return [
                'language' => [
                    'class' => LanguageBehavior::className(),
                ],
            ];
        }
    
        /**
         * @inheritdoc
         */
        public function rules()
        {
            return [
                [
                    [ 'sort' ],
                    'integer',
                ],
                [
                    [ 'color' ],
                    'string',
                ],
                [
                    [ 'value' ],
                    'number',
                ],
                [
                    [ 'status' ],
                    'boolean',
                ],
            ];
        }
    
        /**
         * @inheritdoc
         */
        public function attributeLabels()
        {
            return [
                'id'     => Yii::t('order', 'ID'),
                'sort'   => Yii::t('order', 'Sort'),
                'value'  => Yii::t('order', 'Value'),
                'status' => Yii::t('order', 'Status'),
                'color'  => Yii::t('order', 'Color'),
            ];
        }
    
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getLabelLangs()
        {
            return $this->hasMany(LabelLang::className(), [ 'label_id' => 'id' ]);
        }
    
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getLanguages()
        {
            return $this->hasMany(Language::className(), [ 'id' => 'language_id' ])
                        ->viaTable('label_lang', [ 'label_id' => 'id' ]);
        }
    
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getOrders()
        {
            return $this->hasMany(Order::className(), [ 'label_id' => 'id' ]);
        }
    }
