<?php
    /**
     * @var View         $this
     * @var string       $content
     * @var SeoComponent $seo
     * @var User         $user
     * @var Category[]   $categories
     */
    use artbox\catalog\models\Category;
    use artbox\core\components\SeoComponent;
    use artbox\core\models\Feedback;
    use artbox\core\models\Image;
    use artbox\core\models\Page;
    use artbox\core\models\User;
    use common\models\LoginForm;
    use common\models\Newsletter;
    use common\models\SearchForm;
    use common\models\Settings;
    use frontend\assets\AppAsset;
    use frontend\widgets\LangLink;
    use yii\base\Model;
    use yii\bootstrap\ActiveForm;
    use yii\bootstrap\Html;
    use yii\helpers\Url;
    use yii\web\View;
    use yii\widgets\Breadcrumbs;
    
    AppAsset::register($this);
    /**
     * @var \artbox\order\models\Customer $user
     */
    $user = \Yii::$app->user->identity;
    $seo = Yii::$app->get('seo');
    $feedback = new Feedback();
    $settings = Settings::getInstance();
    $controller = Yii::$app->controller;
    $default_controller = Yii::$app->defaultRoute;
    
    $categories = \artbox\catalog\models\Category::find()
                                                 ->with('categories.lang.alias', 'lang.alias')
                                                 ->where([ 'level' => 0 ])
                                                 ->all();
    
    /**
     * @var LoginForm $loginForm
     */
    $loginForm = \Yii::createObject(
        [
            'class'     => LoginForm::className(),
            'returnUrl' => \Yii::$app->request->absoluteUrl,
        ]
    );
    /**
     * @var Newsletter $newsletter
     */
    $newsletter = \Yii::createObject(
        [
            'class' => Newsletter::className(),
        ]
    );
    $isHome = ( ( $controller->id === $default_controller ) && ( $controller->action->id === $controller->defaultAction ) ) ? true : false;
    /**
     * @var Page[] $pages
     */
    $pages = Page::find()
                 ->where([ 'in_menu' => true ])
                 ->with('lang.alias')
                 ->orderBy(
                     [
                         'sort' => SORT_ASC,
                         'id'   => SORT_ASC,
                     ]
                 )
                 ->all();
    $logo = null;
    if ($settings->logo) {
        $logo_img = Image::findOne($settings->logo);
        if ($logo_img) {
            $logo = $logo_img->getUrl() ?? $logo;
        }
    }
    
    $this->registerMetaTag(
        [
            'name'    => 'description',
            'content' => $seo->desc,
        ]
    );
    $this->registerMetaTag(
        [
            'name'    => 'robots',
            'content' => $seo->robots,
        ]
    );
    
    $preloader = <<<JS
 $(".preloaded_")
                          .removeClass("preloaded_");
                      $(".preload_")
                          .animate({opacity: '0'}, 300);
                      setTimeout(
                          function() {
                              $(".preload_")
                                  .remove();
                          }, 300
                      );
JS;
    $this->registerJs($preloader, View::POS_READY);

if((Yii::$app->controller->id ==='category'||'blog')) {
    $canonicalUrl = Yii::$app->request->getHostInfo(). '/' . Yii::$app->request->getPathInfo();
    $canonicalUrl = rtrim($canonicalUrl, '/index');
    $this->registerLinkTag(
        [
            'href' => $canonicalUrl,
            'rel'  => 'canonical'
        ]
    );
}

?>

<?php $this->beginPage() ?>
  
  <!DOCTYPE html>
  <html lang="<?= \Yii::$app->language ?>">
    <head>
      <meta charset="<?= \Yii::$app->charset ?>">
      <meta name="viewport" content="width=device-width, initial-scale=1">
      <link rel="icon" href="/img/favicon.ico" type="image/x-icon">
        <?= Html::csrfMetaTags() ?>
      <title><?= Html::encode($seo->title) ?></title>
        <?php $this->head() ?>
    </head>
    <body class="preloaded_">
      <style>
        .preloaded_ {
          overflow: hidden;
          width: 100%;
          height: 100vh
        }
        
        #fountainG {
          position: absolute;
          width: 234px;
          height: 28px;
          margin: auto;
          top: calc(50% - 28px);
          left: calc(50% - 117px)
        }
        
        .fountainG {
          position: absolute;
          top: 0;
          background-color: #f60;
          width: 28px;
          height: 28px;
          animation-name: bounce_fountainG;
          -o-animation-name: bounce_fountainG;
          -ms-animation-name: bounce_fountainG;
          -webkit-animation-name: bounce_fountainG;
          -moz-animation-name: bounce_fountainG;
          animation-duration: 1.5s;
          -o-animation-duration: 1.5s;
          -ms-animation-duration: 1.5s;
          -webkit-animation-duration: 1.5s;
          -moz-animation-duration: 1.5s;
          animation-iteration-count: infinite;
          -o-animation-iteration-count: infinite;
          -ms-animation-iteration-count: infinite;
          -webkit-animation-iteration-count: infinite;
          -moz-animation-iteration-count: infinite;
          animation-direction: normal;
          -o-animation-direction: normal;
          -ms-animation-direction: normal;
          -webkit-animation-direction: normal;
          -moz-animation-direction: normal;
          transform: scale(.3);
          -o-transform: scale(.3);
          -ms-transform: scale(.3);
          -webkit-transform: scale(.3);
          -moz-transform: scale(.3);
          border-radius: 19px;
          -o-border-radius: 19px;
          -ms-border-radius: 19px;
          -webkit-border-radius: 19px;
          -moz-border-radius: 19px
        }
        
        #fountainG_1 {
          left: 0;
          animation-delay: .6s;
          -o-animation-delay: .6s;
          -ms-animation-delay: .6s;
          -webkit-animation-delay: .6s;
          -moz-animation-delay: .6s
        }
        
        #fountainG_2 {
          left: 29px;
          animation-delay: .75s;
          -o-animation-delay: .75s;
          -ms-animation-delay: .75s;
          -webkit-animation-delay: .75s;
          -moz-animation-delay: .75s
        }
        
        #fountainG_3 {
          left: 58px;
          animation-delay: .9s;
          -o-animation-delay: .9s;
          -ms-animation-delay: .9s;
          -webkit-animation-delay: .9s;
          -moz-animation-delay: .9s
        }
        
        #fountainG_4 {
          left: 88px;
          animation-delay: 1.05s;
          -o-animation-delay: 1.05s;
          -ms-animation-delay: 1.05s;
          -webkit-animation-delay: 1.05s;
          -moz-animation-delay: 1.05s
        }
        
        #fountainG_5 {
          left: 117px;
          animation-delay: 1.2s;
          -o-animation-delay: 1.2s;
          -ms-animation-delay: 1.2s;
          -webkit-animation-delay: 1.2s;
          -moz-animation-delay: 1.2s
        }
        
        #fountainG_6 {
          left: 146px;
          animation-delay: 1.35s;
          -o-animation-delay: 1.35s;
          -ms-animation-delay: 1.35s;
          -webkit-animation-delay: 1.35s;
          -moz-animation-delay: 1.35s
        }
        
        #fountainG_7 {
          left: 175px;
          animation-delay: 1.5s;
          -o-animation-delay: 1.5s;
          -ms-animation-delay: 1.5s;
          -webkit-animation-delay: 1.5s;
          -moz-animation-delay: 1.5s
        }
        
        #fountainG_8 {
          left: 205px;
          animation-delay: 1.64s;
          -o-animation-delay: 1.64s;
          -ms-animation-delay: 1.64s;
          -webkit-animation-delay: 1.64s;
          -moz-animation-delay: 1.64s
        }
        
        @keyframes bounce_fountainG {
          0% {
            transform: scale(1);
            background-color: #005bac
          }
          100% {
            transform: scale(.3);
            background-color: #fff
          }
        }
        
        @-o-keyframes bounce_fountainG {
          0% {
            -o-transform: scale(1);
            background-color: #005bac
          }
          100% {
            -o-transform: scale(.3);
            background-color: #fff
          }
        }
        
        @-ms-keyframes bounce_fountainG {
          0% {
            -ms-transform: scale(1);
            background-color: #005bac
          }
          100% {
            -ms-transform: scale(.3);
            background-color: #fff
          }
        }
        
        @-webkit-keyframes bounce_fountainG {
          0% {
            -webkit-transform: scale(1);
            background-color: #005bac
          }
          100% {
            -webkit-transform: scale(.3);
            background-color: #fff
          }
        }
        
        @-moz-keyframes bounce_fountainG {
          0% {
            -moz-transform: scale(1);
            background-color: #005bac
          }
          100% {
            -moz-transform: scale(.3);
            background-color: #fff
          }
        }
      </style>
      <div class="preload_" style="background-color:#fff;position: fixed;width:100%;height:100vh;padding:0;margin:0;z-index: 99999999;top: 0;left: 0;overflow: hidden;">
        <div id="fountainG">
          <div id="fountainG_1" class="fountainG"></div>
          <div id="fountainG_2" class="fountainG"></div>
          <div id="fountainG_3" class="fountainG"></div>
          <div id="fountainG_4" class="fountainG"></div>
          <div id="fountainG_5" class="fountainG"></div>
          <div id="fountainG_6" class="fountainG"></div>
          <div id="fountainG_7" class="fountainG"></div>
          <div id="fountainG_8" class="fountainG"></div>
        </div>
      </div>
        
        <?php $this->beginBody() ?>
      <!-- Google Analytics -->
      <script>
          (function(i, s, o, g, r, a, m) {
              i[ 'GoogleAnalyticsObject' ] = r;
              i[ r ] = i[ r ] || function() {
                      (i[ r ].q = i[ r ].q || []).push(arguments)
                  }, i[ r ].l = 1 * new Date();
              a = s.createElement(o), m = s.getElementsByTagName(o)[ 0 ];
              a.async = 1;
              a.src = g;
              m.parentNode.insertBefore(a, m)
          })(window, document, 'script', 'https://www.google-analytics.com/analytics.js', 'ga');

          ga('create', '<?=$settings->ga_code?>', 'auto');
          ga('send', 'pageview');
      
      </script>
      <div id="all">
        <header>
          
          <!-- *** TOP ***
_________________________________________________________ -->
          <div id="top" class="hidden-sm hidden-xs">
            <div class="container">
              <div class="row">
                <div class="col-xs-6 left-top-nav">
                    <?php
                        foreach ($pages as $page) {
                            echo Html::a(
                                $page->lang->title,
                                [
                                    'page/view',
                                    'id' => $page->id,
                                ]
                            );
                        }
                        echo Html::a(
                            \Yii::t('app', 'Контакти'),
                            [
                                'site/contact',
                            ]
                        );
                    ?>
                </div>
                <div class="col-xs-6 right-top-nav">
                  <div class="inline-block lang-link">
                      <?php
                          echo LangLink::widget();
                      ?>
                  </div>
                  <div class="inline-block">
                    <span class="top-phone"><i class="fa fa-phone"></i>&ensp;<?php echo implode('  ', explode(';', $settings->phone)) ?></span>
                    <a href="#" data-toggle="modal" data-target="#callback-modal" class="link-underline_dott">
                        <?php echo Yii::t('app','Callback') ?>
                    </a>
                  </div>
                  <div class="inline-block login">
                      <?php
                          if (\Yii::$app->user->isGuest) {
                              ?>
                            <a href="#" data-toggle="modal" data-target="#login-modal"><i class="fa fa-sign-in"></i>
                              <span><?=Yii::t('app','Enter')?></span></a>
                              <?php
                          } else {
                              echo Html::a($user->username, [ 'account/index' ]);
                          }
                      ?>
                  </div>
                </div>
              </div>
            </div>
          </div>
          
          <!-- *** TOP END *** -->
          
          <!-- *** NAVBAR ***
  _________________________________________________________ -->
          
          <div class="navbar-affixed-top" data-spy="affix" data-offset-top="200">
            
            <div class="navbar navbar-default yamm" role="navigation" id="navbar">
              
              <div class="container">


                
                <div class="navbar-header">
                    <?php
                        echo Html::a(
                            Html::img(
                                $logo,
                                [
                                    'alt' => 'logo',
                                ]
                            ),
                            '/',
                            [
                                'class' => 'navbar-brand home',
                            ]
                        )
                    ?>
                
                </div>
                <!--/.navbar-header -->
                <div class="visible-xs visible-sm hidden-md hidden-lg mob-btn-menus">
                  <div class="menu_mob">
                    <div></div>
                    <div></div>
                  </div>
                  <div id="menu-mob-hidden">
                    <div class="style close-menu-mob">
                      Меню
                      <div class="close_mob"></div>
                    </div>
                    <ul class="start-mob-menu">
                      <li class="bg-mob-menu">
                        <a href="#">Каталог</a>
                        <ul>
                            <?php foreach ($categories as $category) { ?>
                              <li>
                                <a href="#"><?= $category->lang->title ?></a>
                                <ul>
                                    <?php foreach ($category->categories as $child) { ?>
                                      <li><a href="<?= Url::to(
                                              [
                                                  'category/view',
                                                  'category' => $child->lang->alias->value,
                                              ]
                                          ) ?>"><?= $child->lang->title ?></a></li>
                                    <?php } ?>
                                </ul>
                              </li>
                            <?php } ?>
                        </ul>
                      </li>
                      <li><a href="/"><?=Yii::t('app','Home')?></a></li>
                      <li>
                          <?php
                              echo Html::a(
                                  \Yii::t('app', 'Sale'),
                                  [
                                      '/special/index',
                                      'type' => 'sale',
                                  ]
                              );
                          ?>
                      </li>
                      <li>
                          <?php
                              echo Html::a(
                                  \Yii::t('app', 'New'),
                                  [
                                      '/special/index',
                                      'type' => 'new',
                                  ]
                              );
                          ?>
                      </li>
                      <li>
                          <?php
                              echo Html::a(
                                  \Yii::t('app', 'Блог'),
                                  [
                                      '/blog/index',
                                  ]
                              );
                          ?>
                      </li>
                      
                      
                      <li class="bg-mob-menu">
                        <a href="#" data-toggle="modal" data-target="#callback-modal">
                            <?php echo "Зворотній зв'язок"; ?>
                        </a>
                      </li>
                    </ul>
                      <div class="style phones-mob-menu" style="text-align: center; color: #fff;margin-top: 10px">
                          <span class="top-phone"><i class="fa fa-phone"></i>&ensp;+38 (044) 490-70-07</span>
                      </div>
                  </div>
                </div>
                
                <div class="hidden-xs hidden-sm menu-header_catalog" id="navigation">
                  <ul class="nav navbar-nav navbar-left">
                    <li class="main-nav-item <?php if ($isHome) {
                        echo 'home-page-menu';
                    } ?>">
                      <a href="#" <?php echo $isHome ? '' : 'role="button" class="dropdown-toggle" data-toggle="dropdown" data-hover="dropdown" data-delay="200"'; ?>><span class="btn-like"><?php echo \Yii::t(
                                  'app',
                                  'Catalog'
                              ); ?><i class="fa fa-bars" aria-hidden="true"></i></span></a>
                    
                    </li>
                    <li class="main-nav-item">
                        <?php
                            echo Html::a(
                                \Yii::t('app', 'Sales'),
                                [
                                    '/special/index',
                                    'type' => 'sale',
                                ]
                            );
                        ?>
                    </li>
                    <li class="main-nav-item">
                        <?php
                            echo Html::a(
                                \Yii::t('app', 'New'),
                                [
                                    '/special/index',
                                    'type' => 'new',
                                ]
                            );
                        ?>
                    </li>
                    <li class="main-nav-item">
                        <?php
                            echo Html::a(
                                \Yii::t('app', 'Blog'),
                                [
                                    '/blog/index',
                                ]
                            );
                        ?>
                    </li>
                  </ul>
                </div>
                <!--/.nav-collapse -->
                
                <div class="cart-item" id="cart">
                  <span class="badge">0</span>
                    <?php
                        echo Html::a(
                            Html::tag(
                                'span',
                                \Yii::t('app', 'Cart'),
                                [
                                    'class' => 'sub-title',
                                ]
                            ),
                            [
                                '/checkout/index',
                            ],
                            [
                                'class' => 'cart-item-link',
                            ]
                        );
                    ?>
                </div>
                
                <div class="search-block" id="search">
                  <div style="display: none;" class="close_search_ico">
                    <div class="fa fa-times"></div>
                  </div>
                    <?php
                        /**
                         * @var Model $search
                         */
                        $search = \Yii::createObject(SearchForm::className());
                        $searchForm = ActiveForm::begin(
                            [
                                'action'  => [ '/search/index' ],
                                'id'      => 'search-form',
                                'method'  => 'get',
                                'options' => [
                                    'class' => 'navbar-form',
                                    'role'  => 'search',
                                ],
                            ]
                        );
                        echo Html::beginTag(
                            'div',
                            [
                                'class' => 'input-group',
                            ]
                        );
                        echo $searchForm->field(
                            $search,
                            'word',
                            [
                                'options' => [
                                    'tag' => false,
                                ],
                            ]
                        )
                                        ->label(false)
                                        ->textInput(
                                            [
                                                'placeholder' => $search->getAttributeLabel('word'),
                                                'name'        => 'word',
                                            ]
                                        );
                        echo Html::tag(
                            'span',
                            Html::submitButton(
                                Html::tag(
                                    'i',
                                    '',
                                    [
                                        'class' => 'fa fa-search',
                                    ]
                                ),
                                [
                                    'class' => 'btn btn-template-main',
                                ]
                            ),
                            [
                                'class' => 'input-group-btn',
                            ]
                        );
                        echo Html::endTag('div');
                        $searchForm::end();
                    ?>
                </div>
                
                <div style="display: none" class="search_ico">
                  <div class="fa fa-search"></div>
                </div>
                
                
                <!--/.nav-collapse -->
              </div>
            </div>
            <!-- /#navbar -->
          </div>
          <!-- *** NAVBAR END *** -->
        </header>
        
        <!-- *** LOGIN MODAL ***
_________________________________________________________ -->
          <?php
              if (\Yii::$app->user->isGuest) {
                  ?>
                <div class="modal fade" id="login-modal" tabindex="-1" role="dialog" aria-labelledby="Login" aria-hidden="true">
                  <div class="modal-dialog modal-sm">
                    
                    <div class="modal-content">
                      <div class="modal-header">
                        <button type="button" class="close" data-dismiss="modal" aria-hidden="true">&times;</button>
                        <h4 class="modal-title text-center" id="Login">
                            <?php echo \Yii::t('app', 'Customer login'); ?>
                        </h4>
                      </div>
                      <div class="modal-body">
                          <?php
                              $login = ActiveForm::begin(
                                  [
                                      'action' => [ '/site/login' ],
                                  ]
                              );
                              echo $login->field($loginForm, 'returnUrl')
                                         ->label(false)
                                         ->hiddenInput();
                              echo $login->field($loginForm, 'username')
                                         ->label(false)
                                         ->textInput(
                                             [
                                                 'placeholder' => $loginForm->getAttributeLabel('username'),
                                             ]
                                         );
                              echo $login->field($loginForm, 'password')
                                         ->label(false)
                                         ->passwordInput(
                                             [
                                                 'placeholder' => $loginForm->getAttributeLabel('Пароль'),
                                             ]
                                         );
                              echo $login->field($loginForm, 'rememberMe')
                                         ->checkbox();
                          ?>
                        <a class="restore_password_" href="<?= Url::to(
                            [
                                '/site/request-password-reset',
      
                            ]
                        ) ?>"><?=Yii::t('app','Restore password')?></a>
                        <div class="text-center">
                            <?php
                                echo Html::submitButton(
                                    \Yii::t('app', 'Login'),
                                    [
                                        'class' => 'btn btn-success',
                                    ]
                                );
                                $login::end();
                            ?>
                        </div>
                        
                        <p class="text-center text-muted">
                            <?php echo \Yii::t('app', 'Not registered yet?'); ?></p>
                        <p class="text-center text-muted">
                          
                            <?php
                                echo Html::a(
                                    Html::tag('strong', \Yii::t('app', 'Register now!')),
                                    [
                                        '/site/login',
                                    ]
                                );
                            ?>
                        </p>
                      
                      </div>
                    </div>
                  </div>
                </div>
                  <?php
              }
          ?>
        
        <!-- *** LOGIN MODAL END *** -->
        
        
        <!-- *** SUCCESS MODAL BEGIN ***
_________________________________________________________ -->
          <?php
              if ($msg = \Yii::$app->session->getFlash('success')) {
                  ?>
                <div class="modal fade" id="success-modal" tabindex="-1" role="dialog" aria-labelledby="Success" aria-hidden="true">
                  <div class="modal-dialog modal-sm">
                    
                    <div class="modal-content">
                      <div class="modal-header">
                        <button type="button" class="close" data-dismiss="modal" aria-hidden="true">&times;</button>
                      </div>
                      <div class="modal-body">
                          <?php echo $msg; ?>
                      </div>
                    </div>
                  </div>
                </div>
                  <?php
                  $this->registerJs("$('#success-modal').modal('show');");
              }
          ?>
        
        <!-- *** Breadcrumbs *** -->
        <!-- *** FEEDBACK MODAL BEGIN *** -->
          <?php
          ?>
          
          <?php
              $callback = new Feedback(
                  [
                      'scenario'  => Feedback::SCENARIO_CALLBACK,
                      'returnUrl' => Url::current([], true),
                  ]
              );
          ?>
        <div class="modal fade" id="callback-modal" tabindex="-1" role="dialog" aria-labelledby="Login" aria-hidden="true">
          <div class="modal-dialog modal-sm">
            
            <div class="modal-content">
              <div class="modal-header">
                <button type="button" class="close" data-dismiss="modal" aria-hidden="true">&times;</button>
                <h4 class="modal-title callback text-center" id="Login">Зворотній зв'язок</h4>
              </div>
              <div class="modal-body">
                  <?php
                      $form = ActiveForm::begin(
                          [
                              'action' => [ 'site/callback' ],
                          ]
                      );
                      echo $form->field($callback, 'returnUrl')
                                ->label(false)
                                ->hiddenInput();
                      echo $form->field($callback, 'name')
                                ->label(false)
                                ->textInput(
                                    [
                                        'placeholder' => $callback->getAttributeLabel('Ваше ім\'я'),
                                    ]
                                );
                      echo $form->field($callback, 'phone')
                                ->label(false)
                                ->textInput(
                                    [
                                        'placeholder' => $callback->getAttributeLabel('Номер телефона'),
                                    ]
                                );
                      echo Html::tag(
                          'p',
                          Html::submitButton(
                              Html::icon(
                                  'sign-in',
                                  [
                                      'prefix' => 'fa fa-',
                                  ]
                              ) . \Yii::t('app', 'Відправити'),
                              [
                                  'class' => 'btn btn-template-main',
                              ]
                          ),
                          [
                              'class' => 'text-center',
                          ]
                      );
                      $form::end();
                  ?>
              </div>
            </div>
          </div>
        </div>

          <!--catalog-menuq-->

          <?php
          if (!$isHome) {
              echo '<div class="style" style="position: absolute;">';
              echo '<div class="container">';
              echo '<div class="row">';
              echo '<div class="catalog-menu-wrapper-start hidden-xs hidden-sm col-md-3 col-lg-3" style="position: relative;top: 0;">';
              echo $this->render(
                  '_category_menu',
                  [
                      'isHome' => $isHome,
                  ]
              );
              echo '</div>';
              echo '</div>';
              echo '</div>';
              echo '</div>';
          }
          ?>
          <!--end-catalog-menuq-->

        <!-- *** FEEDBACK MODAL END *** -->
          <?php
              if (!$isHome) {
                  ?>
                <div id="heading-breadcrumbs">
                  <div class="container">
                      <?= Breadcrumbs::widget(
                          [
                              'links'    => isset($this->params[ 'breadcrumbs' ]) ? $this->params[ 'breadcrumbs' ] : [],
                              'homeLink' => [
                                  'label' => \Yii::t('app', 'Home'),
                                  'url'   => [ '/site/index' ],
                              ],
                          ]
                      ) ?>
                  </div>
                </div>
                  <?php
              }
          ?>
        <!-- *** crumbs END *** -->

          <?= $content ?>
        
        <!-- *** FOOTER *** -->
        
        <footer id="footer">
          <div class="container">
            <div class="row">
              <div class="col-md-3 col-sm-6">
                <h4>Про нас</h4>
                
                <p><?= $settings->about ?></p>
                
                <hr class="hidden-md hidden-lg hidden-sm">
              
              </div>
              
              <div class="col-md-3 col-sm-6">
                
                <h4>Розділи</h4>
                
                <div class="blog-entries">
                    
                    <?php foreach ($pages as $page) { ?>
                      <div class="item same-height-row clearfix">
                        <div class="style name">
                            <?= Html::a(
                                $page->lang->title,
                                [
                                    'page/view',
                                    'id' => $page->id,
                                ]
                            ) ?>
                        </div>
                      </div>
                    <?php } ?>
                  
                  <div class="item same-height-row clearfix">
                    <div class="style name">
                        <?= Html::a(\Yii::t('app', 'Контакти'), [ 'site/contact' ]) ?>
                    </div>
                  </div>
                
                </div>
                
                <hr class="hidden-md hidden-lg">
              
              </div>

                <div class="col-md-2 col-sm-6">
                
                <h4>Соціальні мережі</h4>
                
                <p class="socials-links">
                    <?php if (!empty($settings->facebook)) { ?>
                      <a href="<?= $settings->facebook ?>"><i class="fa fa-facebook-official" aria-hidden="true"></i></a>
                    <?php }
                        if (!empty($settings->google)) { ?>
                          <a href="<?= $settings->google ?>"><i class="fa fa-google-plus-square" aria-hidden="true"></i></a>
                        <?php }
                        if (!empty($settings->twitter)) { ?>
                          <a href="<?= $settings->twitter ?>"><i class="fa fa-twitter-square" aria-hidden="true"></i></a>
                            <?php
                        }
                    ?>
                </p>
              
              </div>

                <div class="col-md-4 col-sm-6">
                
                <h4>Контактна інформація</h4>

                  <p>
			Пункт видачі замовлень:<br>
			<?= $settings->street . ', ' . $settings->house ?>, <?= $settings->city . ', ' ?><?= $settings->country ?>
                      <br>
                      <strong>
	                      <?= $settings->email; ?>

                      </strong>
                      <br> <?= $settings->phone; ?>

                </p>
                
                <a href="/site/contact" class="btn btn-small btn-template-main">Написати нам</a>
                
                <hr class="hidden-md hidden-lg hidden-sm">
              
              </div>
            </div>
          </div>
          <!-- /.container -->
        </footer>
        
        <!-- *** FOOTER END *** -->
      
      
      </div>
      <!-- /#all -->
        <?php $this->endBody() ?>
    </body>
  </html>
<?php $this->endPage() ?>
